@@ -29,6 +29,7 @@ if __name__ == "__main__":
     parser.add_argument("-I", "--icorrmax", type=float, default=0.95, help="Maximum intra-cluster correlation")
     parser.add_argument("-x", "--xcorrmin", type=float, default=0.0, help="Minimum extra-cluster correlation")
     parser.add_argument("-X", "--xcorrmax", type=float, default=0.3, help="Maximum extra-cluster correlation")
+    parser.add_argument("-p", "--do_entropy", type=bool, default=False, help="Optional entropy calculation")
     args = parser.parse_args()
     output = Path(args.output)
     epsilon = args.epsilon
@@ -36,6 +37,7 @@ if __name__ == "__main__":
     ncmax = args.ncmax
     nruns = args.runs
     wcmax = args.wclust_f
+    do_ent = args.do_entropy
     icorrmin = args.icorrmin
     icorrmax = args.icorrmax
     xcorrmin = args.xcorrmin
@@ -62,7 +64,7 @@ if __name__ == "__main__":
                                                                wclust_factor=wclust_factor)
         rnstr = "RandNorms" if rand_norms else "ConstNorms"
 
-        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=ncmin, ncmax=ncmax)
+        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=ncmin, ncmax=ncmax, do_entropies=do_ent)
         df_mini_scree_plots = nmf.add_miniscree_plots_from_scree_plot(df_mini_scree_plots, df_scree_plot, nb_clusters)
 
         if itrial % writefreq == 0 or itrial == nruns-1:
