@@ -233,14 +233,15 @@ if __name__ == "__main__":
         min_corr = np.random.uniform(low=0.70, high=0.95)
         # min_corr = 0.70
         max_corr = np.random.uniform(low=0.05, high=0.30)
-        max_corr = 0.30
+        # max_corr = 0.30
         h_size = np.random.randint(low=10, high=20)
-        h_size = 200
+        # h_size = 200
         w_size = np.random.randint(low=10, high=100)
-        w_size = 200
+        # w_size = 200
         rnd_norms = True
         # eps = np.random.uniform(low=0.0, high=0.25)
         eps = 0.10
+        # noinspection PyTupleAssignmentBalance
         gen_M, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
                                                          h_icorr_min=min_corr, h_icorr_max=max_corr, epsilon=eps,
                                                          random_norms=rnd_norms)
@@ -326,7 +327,7 @@ if __name__ == "__main__":
     if os.getenv("imp_do_screeplot_tests", "False").lower() == "true":
 
         nb_clusters = 12
-        nb_clusters = 1
+        # nb_clusters = 1
         min_corr = 0.9
         max_corr = 0.10
         h_size = 40
@@ -392,9 +393,9 @@ if __name__ == "__main__":
                               data=np.random.normal(size=[nb_obs, nb_eco_feat]))
 
         ncomp_eco = 6
-        p_step = 0.05
-        n_step = int(0.4 / p_step)
-        missing_props = [round(i * p_step, 2) for i in range(n_step)]
+        # p_step = 0.05
+        # n_step = int(0.4 / p_step)
+        # missing_props = [round(i * p_step, 2) for i in range(n_step)]
         imp_kmeans = imp.Imputer(method="kmeans",
                                  params={"ngroups": ncomp_eco})
         imp_nmf_proxy = imp.Imputer(method="nmf.proxy",
