@@ -261,27 +261,28 @@ class DependentLocalizedSignals:
         return self
 
 
-def generate_nmf_reconstruction(n_comp: int,
-                                min_intra_corr: float,
-                                max_inter_corr: float,
-                                h_avg_clust_size: int,
-                                w_avg_clust_size: int,
-                                epsilon: float,
-                                random_norms: bool = True):
+def generate_nmf_reconstruction(n_comp: int, n_feat: int, n_obs: int, h_icorr_min: float, h_icorr_max: float,
+                                w_icorr_min=0.0, epsilon: float = 0.10, random_norms: bool = True,
+                                wclust_factor: float = 1.0, w_icorr_max=0.3) -> Tuple[pd.DataFrame]:
+
+    n_clust_h = n_comp
+    n_clust_w = max(1, int(n_clust_h * wclust_factor))
 
     cl_vects_h = utl.generate_clusterized_vectors(veclen=n_comp,
-                                                  nclusters=n_comp,
-                                                  nbvect=n_comp * h_avg_clust_size,
-                                                  clusterminsize=int(h_avg_clust_size/2),
-                                                  max_inter_corr=max_inter_corr,
-                                                  min_intra_corr=min_intra_corr,
+                                                  nclusters=n_clust_h,
+                                                  nbvect=n_feat,
+                                                  clusterminsize=min(n_feat / n_clust_h,
+                                                                     max(5, n_feat / n_clust_h / 3)),
+                                                  max_inter_corr=h_icorr_max,
+                                                  min_intra_corr=h_icorr_min,
                                                   random_norms=random_norms)
     cl_vects_w = utl.generate_clusterized_vectors(veclen=n_comp,
-                                                  nclusters=n_comp,
-                                                  nbvect=n_comp * w_avg_clust_size,
-                                                  clusterminsize=int(w_avg_clust_size/2),
-                                                  max_inter_corr=max_inter_corr,
-                                                  min_intra_corr=min_intra_corr,
+                                                  nclusters=n_clust_w,
+                                                  nbvect=n_obs,
+                                                  clusterminsize=min(n_obs / n_clust_w,
+                                                                     max(5, n_obs / n_clust_w / 3)),
+                                                  max_inter_corr=w_icorr_max,
+                                                  min_intra_corr=w_icorr_min,
                                                   random_norms=random_norms)
     cl_vects_w = cl_vects_w.T
     cl_vects_m = cl_vects_w @ cl_vects_h
@@ -291,6 +292,13 @@ def generate_nmf_reconstruction(n_comp: int,
     return cl_vects_m, cl_vects_w, cl_vects_h, noise
 
 
+def generate_wh_name(w_size, h_size, nb_clusters, min_corr, max_corr, eps, random_norms, censor_indices=None):
+    rnstr = "RandNorms" if random_norms else "ConstNorms"
+    wh_name = f"M{w_size}x{h_size}_nc{nb_clusters}_corrmin{round(min_corr, 2)}_" \
+              f"corrmax{round(max_corr, 2)}_noise{round(eps, 2)}_{rnstr}_mis{censor_indices}.csv"
+    return wh_name
+
+
 if __name__ == "__main__":
     # localisation du modèle GAN
     root_path = root_path.get_root_path()
@@ -317,12 +325,8 @@ if __name__ == "__main__":
         h_avg_csize = np.random.randint(low=10, high=20)
         w_avg_csize = np.random.randint(low=10, high=100)
         eps = np.random.uniform(low=0.0, high=0.25)
-        gen_M, gen_w, gen_h, _ = generate_nmf_reconstruction(n_comp=nb_clusters,
-                                                             min_intra_corr=min_corr,
-                                                             max_inter_corr=max_corr,
-                                                             h_avg_clust_size=h_avg_csize,
-                                                             w_avg_clust_size=w_avg_csize,
-                                                             epsilon=eps,
+        gen_M, gen_w, gen_h, _ = generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_avg_csize, n_obs=w_avg_csize,
+                                                             h_icorr_min=min_corr, h_icorr_max=max_corr, epsilon=eps,
                                                              random_norms=rand_norms)
         rnstr = "RandNorms" if rand_norms else "ConstNorms"
         gen_M.to_csv(res_path / "random_nmf" / f"M_t{itrial}_nc{nb_clusters}_corrmin{round(min_corr, 2)}_"
